#!/usr/bin/env node
"use strict";

var _commander = _interopRequireDefault(require("commander"));

var _package = _interopRequireDefault(require("../package.json"));

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var mkcert = _interopRequireWildcard(require("./mkcert"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function createCA({
  organization,
  countryCode,
  state,
  locality,
  validity,
  key,
  cert
}) {
  //Validate days
  validity = Number.parseInt(validity, 10);
  if (!validity || validity < 0) return console.error('`--validity` must be at least 1 day.'); //Create the certificate

  let ca;

  try {
    ca = await mkcert.createCA({
      organization,
      countryCode,
      state,
      locality,
      validityDays: validity
    });
  } catch (err) {
    return console.error(`Failed to create the certificate. Error: ${err.message}`);
  } //Write certificates


  key = _path.default.resolve(key);

  _fs.default.writeFileSync(key, ca.key);

  console.log(`CA Private Key: ${key}`);
  cert = _path.default.resolve(cert);

  _fs.default.writeFileSync(cert, ca.cert);

  console.log(`CA Certificate: ${cert}`);
  console.log('Please keep the private key in a secure location');
}

async function createCert({
  domains,
  caKey,
  caCert,
  validity,
  key,
  cert
}) {
  //Validate days
  validity = Number.parseInt(validity, 10);
  if (!validity || validity < 0) return console.error('`--validity` must be at least 1 day.'); //Validate addresses

  domains = domains.split(',').map(str => str.trim()); //Split comma separated list of addresses

  if (!domains.length) return console.error('`--domains` must be a comma separated list of ip/domains.'); //Read CA data

  const ca = {}; //Read CA key

  try {
    ca.key = _fs.default.readFileSync(_path.default.resolve(caKey), 'utf-8');
  } catch (err) {
    return console.error(`Unable to read \`${caKey}\`. Please run \`mkcert create-ca\` to create a new certificate authority.`);
  } //Read CA certificate


  try {
    ca.cert = _fs.default.readFileSync(_path.default.resolve(caCert), 'utf-8');
  } catch (err) {
    return console.error(`Unable to read \`${caCert}\`. Please run \`mkcert create-ca\` to create a new certificate authority.`);
  } //Create the certificate


  let tls;

  try {
    tls = await mkcert.createCert({
      domains,
      validityDays: validity,
      caKey: ca.key,
      caCert: ca.cert
    });
  } catch (err) {
    return console.error(`Failed to create the certificate. Error: ${err.message}`);
  } //Write certificates


  key = _path.default.resolve(key);

  _fs.default.writeFileSync(key, tls.key);

  console.log(`Private Key: ${key}`);
  cert = _path.default.resolve(cert);

  _fs.default.writeFileSync(cert, `${tls.cert}\n${ca.cert}`); //Create full chain by combining ca and domain certificate


  console.log(`Certificate: ${cert}`);
}

_commander.default.command('create-ca').option('--organization [value]', 'Organization name', 'Test CA').option('--country-code [value]', 'Country code', 'US').option('--state [value]', 'State name', 'California').option('--locality [value]', 'Locality address', 'San Francisco').option('--validity [days]', 'Validity in days', 365).option('--key [file]', 'Output key', 'ca.key').option('--cert [file]', 'Output certificate', 'ca.crt').action((...args) => {
  const options = args.reverse()[0];
  createCA(options);
});

_commander.default.command('create-cert').option('--ca-key [file]', 'CA private key', 'ca.key').option('--ca-cert [file]', 'CA certificate', 'ca.crt').option('--validity [days]', 'Validity in days', 365).option('--key [file]', 'Output key', 'cert.key').option('--cert [file]', 'Output certificate', 'cert.crt').option('--domains [values]', 'Comma separated list of domains/ip addresses', 'localhost,127.0.0.1').action((...args) => {
  const options = args.reverse()[0];
  createCert(options);
});

_commander.default.version(_package.default.version).parse(process.argv); //Show help by default


if (process.argv.length < 3) _commander.default.outputHelp();